<!-- Do not edit this file. It is automatically generated by API Documenter. -->

[Home](./index.md) &gt; [sip.js](./sip.js.md) &gt; [Dialog](./sip.js.dialog.md)

## Dialog class

Dialog.

<b>Signature:</b>

```typescript
export declare class Dialog 
```

## Remarks

A key concept for a user agent is that of a dialog. A dialog represents a peer-to-peer SIP relationship between two user agents that persists for some time. The dialog facilitates sequencing of messages between the user agents and proper routing of requests between both of them. The dialog represents a context in which to interpret SIP messages. https://tools.ietf.org/html/rfc3261\#section-12

## Constructors

|  Constructor | Modifiers | Description |
|  --- | --- | --- |
|  [(constructor)(core, dialogState)](./sip.js.dialog._constructor_.md) |  | Dialog constructor. |

## Properties

|  Property | Modifiers | Type | Description |
|  --- | --- | --- | --- |
|  [callId](./sip.js.dialog.callid.md) |  | <code>string</code> | Call identifier component of the dialog id. |
|  [core](./sip.js.dialog.core.md) |  | <code>UserAgentCore</code> |  |
|  [dialogState](./sip.js.dialog.dialogstate.md) |  | <code>DialogState</code> |  |
|  [early](./sip.js.dialog.early.md) |  | <code>boolean</code> | A dialog can also be in the "early" state, which occurs when it is created with a provisional response, and then it transition to the "confirmed" state when a 2xx final response received or is sent.<!-- -->Note: RFC 3261 is concise on when a dialog is "confirmed", but it can be a point of confusion if an INVITE dialog is "confirmed" after a 2xx is sent or after receiving the ACK for the 2xx response. With careful reading it can be inferred a dialog is always is "confirmed" when the 2xx is sent (regardless of type of dialog). However a INVITE dialog does have additional considerations when it is confirmed but an ACK has not yet been received (in particular with regard to a callee sending BYE requests). |
|  [id](./sip.js.dialog.id.md) |  | <code>string</code> | A dialog is identified at each UA with a dialog ID, which consists of a Call-ID value, a local tag and a remote tag. The dialog ID at each UA involved in the dialog is not the same. Specifically, the local tag at one UA is identical to the remote tag at the peer UA. The tags are opaque tokens that facilitate the generation of unique dialog IDs. https://tools.ietf.org/html/rfc3261\#section-12 |
|  [localSequenceNumber](./sip.js.dialog.localsequencenumber.md) |  | <code>number &#124; undefined</code> | Local sequence number (used to order requests from the UA to its peer). |
|  [localTag](./sip.js.dialog.localtag.md) |  | <code>string</code> | Local tag component of the dialog id. |
|  [localURI](./sip.js.dialog.localuri.md) |  | <code>URI</code> | Local URI. |
|  [remoteSequenceNumber](./sip.js.dialog.remotesequencenumber.md) |  | <code>number &#124; undefined</code> | Remote sequence number (used to order requests from its peer to the UA). |
|  [remoteTag](./sip.js.dialog.remotetag.md) |  | <code>string</code> | Remote tag component of the dialog id. |
|  [remoteTarget](./sip.js.dialog.remotetarget.md) |  | <code>URI</code> | Remote target. |
|  [remoteURI](./sip.js.dialog.remoteuri.md) |  | <code>URI</code> | Remote URI. |
|  [routeSet](./sip.js.dialog.routeset.md) |  | <code>Array&lt;string&gt;</code> | Route set, which is an ordered list of URIs. The route set is the list of servers that need to be traversed to send a request to the peer. |
|  [secure](./sip.js.dialog.secure.md) |  | <code>boolean</code> | If the request was sent over TLS, and the Request-URI contained a SIPS URI, the "secure" flag is set to true. \*NOT IMPLEMENTED\* |
|  [userAgentCore](./sip.js.dialog.useragentcore.md) |  | <code>UserAgentCore</code> | The user agent core servicing this dialog. |

## Methods

|  Method | Modifiers | Description |
|  --- | --- | --- |
|  [confirm()](./sip.js.dialog.confirm.md) |  | Confirm the dialog. Only matters if dialog is currently early. |
|  [createOutgoingRequestMessage(method, options)](./sip.js.dialog.createoutgoingrequestmessage.md) |  | A request within a dialog is constructed by using many of the components of the state stored as part of the dialog. https://tools.ietf.org/html/rfc3261\#section-12.2.1.1 |
|  [dispose()](./sip.js.dialog.dispose.md) |  | Destructor. |
|  [initialDialogStateForUserAgentClient(outgoingRequestMessage, incomingResponseMessage)](./sip.js.dialog.initialdialogstateforuseragentclient.md) | <code>static</code> | When a UAC receives a response that establishes a dialog, it constructs the state of the dialog. This state MUST be maintained for the duration of the dialog. https://tools.ietf.org/html/rfc3261\#section-12.1.2 |
|  [initialDialogStateForUserAgentServer(incomingRequestMessage, toTag, early)](./sip.js.dialog.initialdialogstateforuseragentserver.md) | <code>static</code> | The UAS then constructs the state of the dialog. This state MUST be maintained for the duration of the dialog. https://tools.ietf.org/html/rfc3261\#section-12.1.1 |
|  [receiveRequest(message)](./sip.js.dialog.receiverequest.md) |  | Requests sent within a dialog, as any other requests, are atomic. If a particular request is accepted by the UAS, all the state changes associated with it are performed. If the request is rejected, none of the state changes are performed.<!-- -->Note that some requests, such as INVITEs, affect several pieces of state.<!-- -->https://tools.ietf.org/html/rfc3261\#section-12.2.2 |
|  [recomputeRouteSet(message)](./sip.js.dialog.recomputerouteset.md) |  | If the dialog identifier in the 2xx response matches the dialog identifier of an existing dialog, the dialog MUST be transitioned to the "confirmed" state, and the route set for the dialog MUST be recomputed based on the 2xx response using the procedures of Section 12.2.1.2. Otherwise, a new dialog in the "confirmed" state MUST be constructed using the procedures of Section 12.1.2.<!-- -->Note that the only piece of state that is recomputed is the route set. Other pieces of state such as the highest sequence numbers (remote and local) sent within the dialog are not recomputed. The route set only is recomputed for backwards compatibility. RFC 2543 did not mandate mirroring of the Record-Route header field in a 1xx, only 2xx. However, we cannot update the entire state of the dialog, since mid-dialog requests may have been sent within the early dialog, modifying the sequence numbers, for example.<!-- -->https://tools.ietf.org/html/rfc3261\#section-13.2.2.4 |
|  [sequenceGuard(message)](./sip.js.dialog.sequenceguard.md) |  | If the remote sequence number was not empty, but the sequence number of the request is lower than the remote sequence number, the request is out of order and MUST be rejected with a 500 (Server Internal Error) response. https://tools.ietf.org/html/rfc3261\#section-12.2.2 |

